@@ -1,4 +1,4 @@
-package cppAdaptive2 v3.0.2;
+package cppAdaptive2 v3.0.3;
 
 use strict;
 use warnings;
@@ -20,12 +20,12 @@ use cppAdaptive2::Inline(
 
 #include "cppAdaptive.cpp"
 
-AV* _update( char* obsVector, char* futVector, char* betaVector, int n_observed, int threads ) {
+AV* _update( char* obsVector, char* futVector, char* betaVector, int n_observed ) {
     string obsVector1(obsVector);
     string futVector1(futVector);
     string betaVector1(betaVector);
 
-    cppAdaptive( obsVector1, futVector1, betaVector1, n_observed, threads );
+    cppAdaptive( obsVector1, futVector1, betaVector1, n_observed );
 
     AV* av = newAV();
     sv_2mortal((SV*)av);
@@ -43,19 +43,17 @@ CPP
 
     # with omp
     inc       => '-I../../../../src',
-    ccflags   => '-std=c++11 -fopenmp',
-    lddlflags => '-shared -O2 -fstack-protector-strong -fopenmp',
+    ccflags   => '-std=c++11 -fopenmp -O3',
+    lddlflags => '-shared -O3 -fstack-protector-strong -fopenmp',
 
     clean_after_build => 0,
     clean_build_area  => 0,
 );
 
 sub update {
-    my ( $obsVector, $futVector, $betaVector, $n_observed, $threads ) = @_;
+    my ( $obsVector, $futVector, $betaVector, $n_observed ) = @_;
 
-    $threads ||= 2;
-
-    return @{ _update( $obsVector, $futVector, $betaVector, $n_observed, $threads ) };
+    return @{ _update( $obsVector, $futVector, $betaVector, $n_observed ) };
 }
 
 1;
@@ -79,9 +77,7 @@ cppAdaptive2 - cppAdaptive2 XS
         4,
     );
 
-    my $threads = 2;
-
-    my ( $newFutVector, $newBetaVector ) = cppAdaptive2::update( $obsVector, $futVector, $betaVector, $n_observed, $threads );
+    my ( $newFutVector, $newBetaVector ) = cppAdaptive2::update( $obsVector, $futVector, $betaVector, $n_observed );
 
 =head1 DESCRIPTION
 
